# pymigratedb

This is a python package to help you to migrate your database. 

It will be useful when you work on frameworks or programming languages that don't have a built-in tool to do it or it's little hard to setup.

## Installation
Run in terminal on your project directory:
```
pip install pymigratedb
```

## Usage

## License
Please, read [license here](./LICENSE.txt).
